Unit GraphConfig;

Interface

Uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, Mask, VCap, RXSpin, rxToolEdit, Spin;

Type
  TFGraphConfig = Class(TForm)
    Label1:                  TLabel;
    GroupBox2:               TGroupBox;
    GroupBox1:               TGroupBox;
    Label2:                  TLabel;
    Label3:                  TLabel;
    Label4:                  TLabel;
    Label6:                  TLabel;
    Label5:                  TLabel;
    cbWantPreview:           TCheckBox;
    cbWantCapture:           TCheckBox;
    cbWantBitmaps:           TCheckBox;
    cbWantDVAudio:           TCheckBox;
    cbDoPreallocCaptureFile: TCheckBox;
    cbUseTempFile:           TCheckBox;
    cbVSources:              TComboBox;
    cbASources:              TComboBox;
    cbVComps:                TComboBox;
    cbAComps:                TComboBox;
    cbWantAudio:             TCheckBox;
    cbVComp:                 TCheckBox;
    cbAComp:                 TCheckBox;
    cbDVResolution:          TComboBox;
    cbPixelFormat:           TComboBox;
    feCaptureFile:           TFilenameEdit;
    Button1:                 TButton;
    Button2:                 TButton;
    Label7:                  TLabel;
    Label8:                  TLabel;
    cbWantAudioPreview:      TCheckBox;
    feTempFile:              TFilenameEdit;
    sePreallocSize:          TSpinEdit;
    Procedure cbWantPreviewClick(Sender: TObject);
    Procedure cbWantAudioClick(Sender: TObject);
    Procedure cbWantCaptureClick(Sender: TObject);
    Procedure cbUseTempFileClick(Sender: TObject);
    Procedure cbVCompClick(Sender: TObject);
    Procedure cbACompClick(Sender: TObject);
    Procedure FormCreate(Sender: TObject);
    Procedure cbDoPreallocCaptureFileClick(Sender: TObject);
    Procedure Button1Click(Sender: TObject);
  Private
    { Private declarations }
  Public
    { Public declarations }
  End;

Function EditGraphConfig(config: TGraphConfig): Boolean;

Implementation

{$R *.DFM}

Function EditGraphConfig(config: TGraphConfig): Boolean;
Var
  i: Integer;
Begin
  With TFGraphConfig.Create(Application) Do
    Try
      cbWantPreview.Checked := config.WantPreview;
      cbWantCapture.Checked := config.WantCapture;
      cbWantBitmaps.Checked := config.WantBitmaps;
      cbWantDVAudio.Checked := config.WantDVAudio;
      cbDoPreallocCaptureFile.Checked := config.DoPreallocFile;
      cbUseTempFile.Checked := config.UseTempFile;
      cbWantAudio.Checked := config.WantAudio;
      cbWantAudioPreview.Checked := config.WantAudioPreview;
      cbVComp.Checked := True;
      cbAComp.Checked := True;
      feCaptureFile.FileName := config.CaptureFileName;
      feTempFile.FileName := config.TempCaptureFileName;
      cbDVResolution.ItemIndex := Integer(config.DVResolution);
      cbPixelFormat.ItemIndex := Integer(config.PixelFormat);
      sePreallocSize.Value := config.PreallocFileSize;

      For i := 0 To cbVSources.Items.Count - 1 Do
        If cbVSources.Items[i] = config.VCapSource Then
        Begin
          cbVSources.ItemIndex := i;
          break;
        End;
      For i := 0 To cbASources.Items.Count - 1 Do
        If cbASources.Items[i] = config.ACapSource Then
        Begin
          cbASources.ItemIndex := i;
          break;
        End;
      For i := 0 To cbVComps.Items.Count - 1 Do
        If cbVComps.Items[i] = config.VComp Then
        Begin
          cbVComps.ItemIndex := i;
          break;
        End;
      For i := 0 To cbAComps.Items.Count - 1 Do
        If cbAComps.Items[i] = config.AComp Then
        Begin
          cbAComps.ItemIndex := i;
          break;
        End;

      cbVComp.Checked := cbVComps.ItemIndex >= 0;
      cbAComp.Checked := cbAComps.ItemIndex >= 0;

      cbWantPreviewClick(nil);
      cbWantAudioClick(nil);
      cbWantCaptureClick(nil);
      cbUseTempFileClick(nil);
      cbVCompClick(nil);
      cbACompClick(nil);
      cbDoPreallocCaptureFileClick(nil);

      Result := ShowModal = mrOk;
      If Result Then
      Begin
        config.Clear;
        config.WantPreview := cbWantPreview.Checked;
        config.WantCapture := cbWantCapture.Checked;
        config.WantBitmaps := cbWantBitmaps.Checked;
        config.WantDVAudio := cbWantDVAudio.Checked;
        config.DoPreallocFile := cbDoPreallocCaptureFile.Checked;
        config.UseTempFile := cbUseTempFile.Checked;
        config.WantAudio := cbWantAudio.Checked;
        config.WantAudioPreview := cbWantAudioPreview.Checked;

        config.PreallocFileSize := sePreallocSize.Value;
        config.CaptureFileName  := feCaptureFile.FileName;
        config.TempCaptureFileName := feTempFile.FileName;
        If cbDVResolution.ItemIndex >= 0 Then
          config.DVResolution := TDVResolution(cbDVResolution.ItemIndex);
        If cbPixelFormat.ItemIndex >= 0 Then
          config.PixelFormat := TPixelFormat(cbPixelFormat.ItemIndex);

        config.VCapSource := cbVSources.Text;
        config.ACapSource := cbASources.Text;
        If cbVComp.Checked Then
          config.VComp := cbVComps.Text;
        If cbAComp.Checked Then
          config.AComp := cbAComps.Text;
        config.VCompState := '';
      End;
    Finally
      Free;
    End;
End;

Procedure TFGraphConfig.cbWantPreviewClick(Sender: TObject);
Begin
  cbWantBitmaps.Enabled := cbWantPreview.Checked;
  cbWantAudioPreview.Enabled := cbWantPreview.Checked;
End;

Procedure TFGraphConfig.cbWantAudioClick(Sender: TObject);
Begin
  cbASources.Enabled := cbWantAudio.Checked;
  cbAComp.Enabled  := cbWantCapture.Checked And cbWantAudio.Checked;
  cbAComps.Enabled := cbWantCapture.Checked And cbWantAudio.Checked;
End;

Procedure TFGraphConfig.cbWantCaptureClick(Sender: TObject);
Begin
  feCaptureFile.Enabled := cbWantCapture.Checked;
  cbDoPreallocCaptureFile.Enabled := cbWantCapture.Checked;
  cbUseTempFile.Enabled := cbWantCapture.Checked;
  cbVComps.Enabled := cbWantCapture.Checked;
  cbVComp.Enabled  := cbWantCapture.Checked;
  cbAComps.Enabled := cbWantCapture.Checked;
  cbAComp.Enabled  := cbWantCapture.Checked;
End;

Procedure TFGraphConfig.cbUseTempFileClick(Sender: TObject);
Begin
  feTempFile.Enabled := cbUseTempFile.Checked;
End;

Procedure TFGraphConfig.cbVCompClick(Sender: TObject);
Begin
  cbVComps.Enabled := cbWantCapture.Checked And cbVComp.Checked;
End;

Procedure TFGraphConfig.Button1Click(Sender: TObject);
Begin
  If cbASources.ItemIndex = -1 Then
  Begin
    cbWantAudio.Checked := False;
    cbWantAudioClick(cbWantAudio);
  End;
End;

Procedure TFGraphConfig.cbACompClick(Sender: TObject);
Begin
  cbAComps.Enabled := cbWantCapture.Checked And cbWantAudio.Checked And cbAComp.Checked;
End;

Procedure TFGraphConfig.FormCreate(Sender: TObject);
Var
  s: TStringList;
Begin
  s := GetVideoDevicesList;
  Try
    cbVSources.Items.Assign(s);
  Finally
    s.Free;
  End;

  s := GetAudioDevicesList;
  Try
    cbASources.Items.Assign(s);
  Finally
    s.Free;
  End;

  s := GetVideoCompressorsList;
  Try
    cbVComps.Items.Assign(s);
  Finally
    s.Free;
  End;

  s := GetAudioCompressorsList;
  Try
    cbAComps.Items.Assign(s);
  Finally
    s.Free;
  End;
End;

Procedure TFGraphConfig.cbDoPreallocCaptureFileClick(Sender: TObject);
Begin
  sePreallocSize.Enabled := cbDoPreallocCaptureFile.Checked;
End;

End.

